@@ -27,6 +27,18 @@ class CommandLineOptions(dict):
         if name in self:            return dict.__getitem__(self, name)
         else:                       return None
 
+    def write_config_file(self, fileh_or_path, sep='=', ordered_keys=None):
+        """Write options into a format that can be later read with read_config_file"""
+        with (fileh_or_path if isinstance(fileh_or_path, io.IOBase)
+              else open(fileh_or_path, 'w')) as fhw:
+            ordered_keys=ordered_keys if ordered_keys is not None else sorted(self.keys())
+            for key in ordered_keys:
+                value=self[key]
+                if type(value) is list:
+                    fhw.write(f'{key} {sep} {" ".join(value)}\n')
+                else:
+                    fhw.write(f'{key} {sep} {value}\n')
+        
         
 class NoTracebackError(Exception):
     """Exception class which, when raised, shows the error message only, without traceback.
@@ -65,7 +77,7 @@ set_up_no_traceback_error()
 
 def command_line_options(default_opt,
                          help_msg='Command line usage:...',
-                         positional_keys='io',
+                         positional_keys='',
                          synonyms={},
                          tolerate_extra=False,
                          tolerated_regexp=[],
@@ -229,10 +241,16 @@ def command_line_options(default_opt,
     for builtin_opt in ['h', 'print_opt']:
         if not builtin_opt in default_opt:
             default_opt[builtin_opt]=False
+        elif type(default_opt[builtin_opt]) is not bool:
+            default_opt[builtin_opt]=(False
+                                       if default_opt[builtin_opt] in ('', '0', 'F', 'False', 0, 0.0)
+                                       else True)
 
     opt=CommandLineOptions()
     arglist=sys.argv[1:] if arglist is None else arglist
-    synonyms['help']='h'                   # built-in synonym
+    for h in ('help', '-help'):
+        synonyms[h]='h'                   # built-in synonym
+        
 
     ## checking default_opt and positional_keys
     for opt_key in default_opt:
@@ -470,6 +488,7 @@ def read_config_file(fileh_or_path, types_from=None, sep='=', comment_char='#'):
     o : str   = outputfile
 
     Using a default opt to coerce types:
+
     >>> def_opt={'i':'inputfile',  'n':5,  'o':''}
     ... read_config_file('example_config.txt', types_from=def_opt)
     i : str   = inputfile
@@ -477,9 +496,11 @@ def read_config_file(fileh_or_path, types_from=None, sep='=', comment_char='#'):
     o : str   = outputfile
 
     **Combining read_config_file and command_line_opt**
+
     Options have built-in values (initial ``def_opt``).
     Some may be overriden by a configuration file (``conf_opt``). 
-    Then again, some may be overriden by command line options (``final opt``)
+    Then again, some may be overriden by command line options (``opt``):
+
     >>> def_opt = {'i':'inputfile',  'n':5,  'o':''}
     ... conf_opt = read_config_file('example_config.txt', types_from=def_opt)
     ... def_opt.update(conf_opt)  
